@@ -1,5 +1,6 @@
 #include "main.h"
-#include "SDL_image.h"
+#include <SDL_image.h>
+#include <string.h>
 
 #define PATHNUM 6
 #define BPP 0
@@ -12,15 +13,15 @@ char DATAPATH[200]=DATADIR;
 const char PATH[PATHNUM][200]={DATADIR,".","data","../data","Penguin-Command.app/Contents/Resources/data",DATADIR};
 SDL_Surface *Screen,*BackBuffer,*FadeBuffer;
 SDL_Rect blitrect,blitrects[RECTS_NUM];
-int blitrects_num=0,HWAccel=0;
+int blitrects_num=0;
+
 
-#ifdef DATADIR
 void ComplainAndExit(void)
 {
         fprintf(stderr, "Problem: %s\n", SDL_GetError());
         exit(1);
 }
-#endif
+
 int abrand(int a,int b)  //random number between a and b (inclusive)
 {
   return(a+(rand() % (b-a+1)));
@@ -86,26 +87,20 @@ void init_SDL()  // sets the video mode
 //  if ( SDL_Init(SDL_INIT_VIDEO | SDL_INIT_JOYSTICK | SDL_INIT_TIMER | SDL_INIT_AUDIO) < 0 ) {ComplainAndExit();}
   puts("** Init video **");
   if ( SDL_Init(SDL_INIT_VIDEO ) < 0 ) ComplainAndExit();
-  puts("** Init timer **");
-  if ( SDL_Init(SDL_INIT_TIMER ) < 0 ) ComplainAndExit();
+//  puts("** Init timer **");
+//  if ( SDL_Init(SDL_INIT_TIMER ) < 0 ) ComplainAndExit();
   info = SDL_GetVideoInfo();
   if (info->vfmt->BitsPerPixel==8) bpp=16;
   atexit(SDL_Quit);
-  if (HWAccel) {
-    SDL_GL_SetAttribute( SDL_GL_RED_SIZE, 5 );                    
-    SDL_GL_SetAttribute( SDL_GL_GREEN_SIZE, 5 );                  
-    SDL_GL_SetAttribute( SDL_GL_BLUE_SIZE, 5 );
-    SDL_GL_SetAttribute( SDL_GL_DEPTH_SIZE, 16);
-    SDL_GL_SetAttribute( SDL_GL_DOUBLEBUFFER, 1 );
-    flags=flags | SDL_OPENGLBLIT | SDL_OPENGL;
-  }
 // Set the video mode (800x600 at 16-bit depth)  
+  puts("** Set video mode **");
   if (fullscreen)  
     Screen = SDL_SetVideoMode(800, 600, bpp, SDL_FULLSCREEN | flags);
   else 
     { Screen = SDL_SetVideoMode(800, 600, bpp, flags); }
   if ( Screen == NULL ) {ComplainAndExit();}
 // create BackBuffer
+  puts("** Create buffers **");
   BackBuffer = SDL_AllocSurface(Screen->flags,
                                800,
                                600,
@@ -209,16 +204,6 @@ int DoLine (SDL_Surface *Surface, Sint32 X1, Sint32 Y1, Sint32 X2, Sint32 Y2, Ui
    return 0;
 }
 
-// The user's line drawing function
-void Line(Sint32 X1, Sint32 Y1, Sint32 X2, Sint32 Y2, Uint32 Color)
-{
-   lock(Screen);
-
-   /* Draw the line */
-   DoLine(Screen, X1, Y1, X2, Y2, Color, &PutPixel);
-   unlock(Screen);
-}
-
 int DoLinePart (SDL_Surface *Surface, Sint32 X1, Sint32 Y1, Sint32 X2, Sint32 Y2, Sint32 lower, Sint32 upper, Uint32 Color, int Callback (SDL_Surface *Surf, Sint32 X, Sint32 Y, Uint32 Color))
 { 
   Sint32 dx, dy, sdx, sdy, x, y, px, py; 
