@@ -101,10 +101,10 @@ void FinalScore()
     int a;
 
     Blit(0,0,BackPic);
-    PutString(Screen,400-TextWidth("Final Score")/2,200,"Final Score");
+    PutString(Screen,400-SFont_TextWidth("Final Score")/2,200,"Final Score");
     sprintf(text,"%d", Score);
-    PutString(Screen,400-TextWidth(text)/2,250,text);
-    PutString(Screen,400-TextWidth("Enter Your Name:")/2,300,"Enter Your Name:");
+    PutString(Screen,400-SFont_TextWidth(text)/2,250,text);
+    PutString(Screen,400-SFont_TextWidth("Enter Your Name:")/2,300,"Enter Your Name:");
     Update();
     SFont_Input(Screen, 260, 350, 280, Name);
     if (strcmp(Name,"")==0) strcpy(Name,"Anonym. Coward");
@@ -134,14 +134,15 @@ void ShowHiscore()
     SDL_Event WaitEvent;
     
     BlitToBB(0,0,BackPic);
-    PutString(BackBuffer,400-TextWidth("<Penguin Command Hiscores>")/2,70,"<Penguin Command Hiscores>");
+    PutString(BackBuffer,400-SFont_TextWidth("<Penguin Command Hiscores>")/2,70,"<Penguin Command Hiscores>");
     for (i=0;i<10;i++) {
 	sprintf(text,"%s", Player[i]);
 	PutString(BackBuffer,200,150+i*30,text);
 	sprintf(text,"%d", Hiscore[i]);
-	PutString(BackBuffer,600-TextWidth(text),150+i*30,text);
+	PutString(BackBuffer,600-SFont_TextWidth(text),150+i*30,text);
     }
     FadeScreen(1);
+    SDL_WaitEvent(&WaitEvent);
     while ((WaitEvent.type!=SDL_KEYDOWN)&&(WaitEvent.type!=SDL_MOUSEBUTTONDOWN)) {
 	SDL_PollEvent(&WaitEvent);
 	UndrawMouse();
