@@ -9,8 +9,8 @@ void PlaySound(Mix_Chunk *Sample);
 
 extern int sound;
 #ifndef USE_SOUND
-  void *MissileExplosionSound,*BombExplosionSound,*GameoverSound,*CitySound,*ClickSound;
-  void *Music[MUSICNUM];
+  extern void *MissileExplosionSound,*BombExplosionSound,*GameoverSound,*CitySound,*ClickSound;
+  extern void *Music[MUSICNUM];
 #else
   extern Mix_Chunk *MissileExplosionSound,*BombExplosionSound,*GameoverSound,*CitySound,*ClickSound;
   extern Mix_Music *Music[MUSICNUM];
